Skip to contents

A list of hex color codes with the primary, secondary, and accent colors as defined by the Charite Markenportal for use with theme_charite()

Usage

charite_colors

Format

An object of class list of length 27.

Value

A hex color scheme of corporate identity colors

Examples

library(ggplot2)
ggplot(as.data.frame(x = 2, y = 6), aes(x = 2, y = 6)) +
    geom_point(size = 16, color = charite_colors$LILA) +
    theme_charite()