A named list of color palettes conforming to the Charite visual identity.
These palettes can be used with make_charite_palette() and
ggplot2 scale helpers.
A named list of color palettes conforming to the Charite visual identity.
These palettes can be used with make_charite_palette() and
ggplot2 scale helpers.