Hex code color definitions of the official Charite visual identity color scheme
Source:R/charite_colors.R
charite_colors.RdA list of hex color codes with the primary, secondary, and accent colors as
defined by the Charite Markenportal
for use with theme_charite()
Examples
library(ggplot2)
ggplot(as.data.frame(x = 2, y = 6), aes(x = 2, y = 6)) +
geom_point(size = 16, color = charite_colors$LILA) +
theme_charite()