Interpolation or reversion of a Charite color palette
Source:R/make_charite_palette.R
make_charite_palette.RdInternal function for the use of color palettes for continuous data or as many categories as required. This function can be used to create your own custom color palette.
Arguments
- palette
Character name of palette in `charite_palettes or a custom vector of hex codes
- reverse
Boolean indicating whether the palette should be reversed
- ...
Additional arguments passed to
grDevices::colorRampPalette()